<?php
/**
 * @package WordPress
 * @subpackage listio
 */

add_action( 'admin_menu', 'listio_add_admin_menu' );
add_action( 'admin_init', 'listio_settings_init' );

if( !function_exists('listio_add_admin_menu') ): 
	
  	  function listio_add_admin_menu() { 
        add_submenu_page('edit.php?post_type=property', 'Property Settings', 'Property Settings', 'administrator', 'admin/settings.php', 'listio_settings_page');
    }
endif;

if( !function_exists('listio_settings_init') ): 
    function listio_settings_init() {
        wp_enqueue_style('font_awesome', PLUGIN_PATH.'admin/css/font-awesome.css', false, '1.0', 'all');
        wp_enqueue_style('listio_settings_style', PLUGIN_PATH.'admin/css/style.css', false, '1.0', 'all');
        wp_enqueue_script('media-upload');
        wp_enqueue_style('thickbox');
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_script('thickbox');
        wp_enqueue_script('my-upload');
        wp_enqueue_script('settings', PLUGIN_PATH.'admin/js/admin.js', array('wp-color-picker'), '1.0', true);

        wp_localize_script('settings', 'settings_vars', 
            array(  
                'amenities_placeholder' => __('Add new', 'listio'),
                'admin_url'             => get_admin_url(),
                'ajaxurl'               => admin_url('admin-ajax.php'),
                'delete'                => __('Delete', 'listio'),

            )
        );

        register_setting( 'listio_amenity_settings', 'listio_amenity_settings' );
        register_setting( 'listio_notifications_settings', 'listio_notifications_settings' );
        register_setting( 'listio_membership_settings', 'listio_membership_settings' );
    }
endif;

/**
 * Load media files needed for Uploader
 */
if( !function_exists('listio_load_wp_media_files') ): 
    function listio_load_wp_media_files() {
        wp_enqueue_media();
    }
endif;
add_action('admin_enqueue_scripts', 'listio_load_wp_media_files');

require_once 'sections/amenities.php';
require_once 'sections/notifications.php';
require_once 'sections/membership.php';

if( !function_exists('listio_settings_page') ): 
    function listio_settings_page() { 
        $allowed_html = array();
        $active_tab = isset($_GET['tab']) ? wp_kses($_GET['tab'], $allowed_html) : 'amenities';
        $tab = 'listio_amenity_settings';

        switch ($active_tab) {
            case "amenities":
                listio_admin_amenities();
                $tab = 'listio_amenity_settings';
                break;
            case "notifications":
                listio_admin_notifications();
                $tab = 'listio_notifications_settings';
                break;
            case "membership":
                listio_admin_membership();
                $tab = 'listio_membership_settings';
                break;
        }
        ?>

        <div class="listio-wrapper">
            <div class="listio-leftSide">
                <div class="listio-logo"><?php esc_html_e('Property Settings','listio') ?></div>
                <ul class="listio-tabs">

                    <li class="<?php echo $active_tab == 'amenities' ? 'listio-tab-active' : '' ?>">
                        <a href="edit.php?post_type=property&page=admin/settings.php&tab=amenities">
                            <span class="listio-tab-link"><?php esc_html_e('Amenities','listio') ?></span>
                        </a>
                    </li>

                    <li class="<?php echo $active_tab == 'notifications' ? 'listio-tab-active' : '' ?>">
                        <a href="edit.php?post_type=property&page=admin/settings.php&tab=notifications">
                            <span class="listio-tab-link"><?php esc_html_e('Notifications','listio') ?></span>
                        </a>
                    </li>

                    <li class="<?php echo $active_tab == 'membership' ? 'listio-tab-active' : '' ?>">
                        <a href="edit.php?post_type=property&page=admin/settings.php&tab=membership">
                           <span class="listio-tab-link"><?php esc_html_e('Membership','listio') ?></span>
                        </a>
                    </li>

                </ul>
            </div>
            <div class="listio-content">
                <form action='options.php' method='post'>
                    <?php
                    wp_nonce_field('update-options');
                    settings_fields($tab);
                    do_settings_sections($tab);
                    submit_button();
                    ?>
                </form>
            </div>
            <div class="clearfix"></div>
        </div>

        <?php
    }
endif;
if (!function_exists('listio_compare_position')) :
    function listio_compare_position($a, $b) {
        return $a["position"] - $b["position"];
    }
endif;
?>